import roman
import unittest

class TestRomanNumerals(unittest.TestCase):

  def testCreateThousand(self):
    thousand = roman.RomanNumeral("M")
    self.assertEqual(thousand.value(), 1000)

  def testCreateTwoThousand(self):
    two_thousand = roman.RomanNumeral("MM")
    self.assertEqual(two_thousand.value(), 2000)

  def testCreateThreeThousand(self):
    three_thousand = roman.RomanNumeral("MMM")
    self.assertEqual(three_thousand.value(), 3000)

  def testWrongInputToConstructor(self):
    self.assertRaises(ValueError, roman.RomanNumeral, 23)
    self.assertRaises(ValueError, roman.RomanNumeral, [23])

  def testNonLegalStringValues(self):
    self.assertRaises(ValueError, roman.RomanNumeral, "")
    self.assertRaises(ValueError, roman.RomanNumeral, "howdy")
    self.assertRaises(ValueError, roman.RomanNumeral, "MMMM")

  def testIllegalSum(self):
    three_thousand = roman.RomanNumeral("MMM")
    one_thousand   = roman.RomanNumeral("M")
    self.assertRaises(ValueError, one_thousand.sum, three_thousand)

  def testLegalSum(self):
    two_thousand = roman.RomanNumeral("MM")
    one_thousand = roman.RomanNumeral("M")
    three_thousand = two_thousand.sum(one_thousand)
    self.assertEqual(three_thousand.value(), 3000)

if __name__ == "__main__":
  unittest.main()
